14.89. cdist-type__package_pacman(7) — cdist 4.8.1 documentation

# 14.89. cdist-type__package_pacman(7)

## 14.89.1. NAME

cdist-type__package_pacman - Manage packages with pacman

## 14.89.2. DESCRIPTION

Pacman is usually used on the Archlinux distribution to manage packages.

## 14.89.3. REQUIRED PARAMETERS

None

## 14.89.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 14.89.5. EXAMPLES

    # Ensure zsh in installed
    __package_pacman zsh --state present

    # If you don't want to follow pythonX packages, but always use python
    __package_pacman python --state present --name python2

    # Remove obsolete package
    __package_pacman puppet --state absent

## 14.89.6. SEE ALSO

cdist-type__package(7)

## 14.89.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 14.89.8. COPYING

Copyright (C) 2011-2012 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.